# -*- coding: utf-8 -*-
from PyQt5.QtWidgets import QAction, QMessageBox, QFileDialog
from PyQt5.QtGui import QIcon
from PyQt5.QtWebKitWidgets import QWebView, QWebPage
from PyQt5.QtCore import QUrl # , Qt, QObject
from qgis.core import QgsVectorLayer, QgsMapLayer, QgsProject  # , QgsRasterLayer
#from qgis.gui import *
import os

class plugin():
  def __init__(self, iface):
    self.iface= iface

  def initGui(self): # Pour ajouter les commandes du plugin (boutons, menus...) à l'interface de QGIS
    win= self.iface.mainWindow()
    self.toolBar= self.iface.pluginToolBar() # la barre d'outil des Extensions
    pluginPath= os.path.abspath(os.path.dirname(__file__))
    
    self.bouton1= QAction( QIcon(pluginPath +'/icons/logo.png'), "Ouvrir un shapefile", win )
    self.bouton1.triggered.connect( self.ouvrirCouche )
    self.toolBar.addAction( self.bouton1 )
    
    self.bouton2= QAction( "Web", win )
    self.bouton2.setToolTip( "Afficher le site internet de QGIS" )
    self.bouton2.triggered.connect( self.ouvrirWeb )
    self.toolBar.addAction( self.bouton2 )
    
    self.bouton3= QAction( "info", win )
    self.bouton3.setToolTip( "informations sur la couche active" )
    self.bouton3.triggered.connect( self.infoCouche )
    self.toolBar.addAction( self.bouton3 )


  def ouvrirCouche(self): # Fonction qui ouvre un fichier Shapefile à choisir par l'utilisateur
    fichierShp, exten= QFileDialog.getOpenFileName( self.iface.mainWindow(), "Choisir le fichier Shapefile à ouvrir",
      "", "Shapefile (*.shp)" )
    if not fichierShp or fichierShp=='':
      return
    macouche= QgsVectorLayer(fichierShp, "Ma couche", 'ogr')
    if not macouche or not macouche.isValid():
      QMessageBox.warning(self.iface.mainWindow(), "Echec",
       "Le fichier \"%s\" n'est pas reconnu par QGIS."% fichierShp.replace('/',os.sep) )
      return
    QgsProject.instance().addMapLayer(macouche)


  def ouvrirWeb(self): # Fonction pour ouvrir le site web : qgis.org
    self.web= QWebView()
    page= QWebPage()
    self.web.setPage(page)
    url= "http://qgis.org"
    self.web.setUrl( QUrl(url) )
    self.web.show()


  def infoCouche(self): # Pour donner qq infos sur la couche active : nom, type, source, champs, etc.
    win= self.iface.mainWindow()
    layer= self.iface.activeLayer()
    if not layer:
      QMessageBox.warning(win, "Remarque", "Cet outil donne des informations sur la couche active.\nMais il n'y a pas de couche active dans le projet actuel." )
      return
    
    types= ['Vecteur','Raster (image)','Plugin','Filet (Mesh)','inconnu','inconnu','inconnu']
    type= layer.type()
    info= "Couche : %s\n\nType : %s \n\nSource :\n%s"% ( layer.name(), types[type], layer.source() )
    if type != QgsMapLayer.VectorLayer:
      QMessageBox.about( win, "Informations sur la couche active", info )
      return
    
    info += "\n\nProvider : %s\n\n"% ( layer.providerType() )
    info += "Nb d'entités : %i\n"% ( layer.featureCount() )
    info += "Nb d'entités sélectionnées : %i\n\n"% ( layer.selectedFeatureCount() )
    chps= str( layer.fields().names() )
    listChp= "'"
    info += "Champs :\n%s\n\n"% ( chps )
    info += "Voulez-vous voir les entités de la couche (zoom et attributs) ?"
    
    ret= QMessageBox.information( win, "Informations sur la couche active", info,
     QMessageBox.No | QMessageBox.Yes, QMessageBox.No )
    if ret != QMessageBox.Yes: return
    
    num= 1
    features= layer.getFeatures()
    for ft in features:
      layer.removeSelection()
      layer.select( ft.id() )
      self.iface.mapCanvas().zoomToSelected( layer )
      ret= QMessageBox.information( win, "Entité n°%i"% num, str(ft.attributes() ),
       QMessageBox.Cancel | QMessageBox.Ok, QMessageBox.Ok )
      if ret != QMessageBox.Ok: break
      num+=1


  def unload(self): # Supprimer menus et boutons
    self.toolBar.removeAction( self.bouton1 )
    self.toolBar.removeAction( self.bouton2 )
    self.toolBar.removeAction( self.bouton3 )
